@@ -11,18 +11,16 @@
 package CPAN::Testers::Report;
 
 use strict;
-use vars qw($VERSION);
+use vars qw($VERSION $__ERRSTR $__RFC2822_RE $__CONFIG_RE);
+use Config;
 use Time::Local ();
 
-$VERSION = '0.02';
-
 local $^W = 1;
 
-sub archname {
-    my $self = shift;
-    $self->{_archname} = shift if @_;
-    return $self->{_archname};
-}
+$VERSION = '0.03';
+
+__PACKAGE__->_rfc2822_compliance_regex(__PACKAGE__->_generate_rfc2822_compliance_regex());
+__PACKAGE__->_configuration_regex(__PACKAGE__->_generate_configuration_regex());
 
 sub comments {
     my $self = shift;
@@ -32,21 +30,14 @@ sub comments {
 
 sub config {
     my $self = shift;
-    if (@_) {
-        $self->{_config} = \shift;
-        (my ($vers_numeric, $vers_float, $extra) = $self->_extract_perl_version($self->{_config})) || return;
-        (my $osname = $self->_extract_osname($self->{_config})) || return;
-        (my $osvers = $self->_extract_osvers($self->{_config})) || return;
-        (my $archname = $self->_extract_archname($self->{_config})) || return;
 
-        $self->interpreter_vers_numeric($vers_numeric);
-        $self->interpreter_vers_float($vers_float);
-        $self->interpreter_vers_extra($extra);
-        $self->osname($osname);
-        $self->osvers($osvers);
-        $self->archname($archname);
+    if (@_) {
+        my $key = shift;
+        return $self->{_config}->{$key};
+    }
+    else {
+        return sort keys %{$self->{_config}};
     }
-    return $self->{_config};
 }
 
 sub dist {
@@ -54,26 +45,26 @@ sub dist {
 
     if (@_) {
         $self->{_dist} = shift;
-        my ($dist, $version, $beta) = $self->_distname_info($self->{_dist});
 
-        if (defined $dist) {
-            $self->dist_name($dist);
-        }
-        else {
-            $self->error("unable to determine distribution name for '$self->{_dist}'");
+        unless (defined $self->{_dist}) {
+            $self->errstr('distribution not specified');
             return;
         }
 
+        my ($dist, $version, $beta) = $self->_distname_info($self->{_dist});
+
+        $self->dist_name($dist);
+
         if (defined $version) {
             $self->dist_vers($version);
         }
         else {
-            $self->error("unable to determine distribution version for '$self->{_dist}'");
+            $self->errstr("unable to determine distribution version for '$self->{_dist}'");
             return;
         }
 
         if ($self->_is_a_perl_release($self->{_dist})) {
-            $self->error('use perlbug for reporting test results against perl herself');
+            $self->errstr('use perlbug for reporting test results against perl herself');
             return;
         }
     }
@@ -93,23 +84,24 @@ sub dist_vers {
     return $self->{_dist_vers};
 }
 
-sub error {
+sub errstr {
     my $self = shift;
-    $self->{__error} = shift if @_;
-    return $self->{__error};
+
+    if (ref $self) {
+        $self->{__errstr} = shift if @_;
+        return $self->{__errstr};
+    }
+    else {
+        $__ERRSTR = shift if @_;
+        return $__ERRSTR;
+    }
 }
 
 sub from {
     my $self = shift;
     if (@_) {
         $self->{_from} = shift;
-
-        my $rfc2822_compliance_regex = $self->_rfc2822_compliance_regex();
-
-        unless ($self->{_from} =~ $rfc2822_compliance_regex) {
-            $self->error('invalid from; is not RFC 2822 compliant');
-            return;
-        }
+        $self->_check_from() || return;
     }
     return $self->{_from};
 }
@@ -118,11 +110,8 @@ sub grade {
     my $self = shift;
     if (@_) {
         $self->{_grade} = shift;
-        unless ($self->{_grade} =~ /^(PASS|FAIL|UNKNOWN|NA)$/i) {
-            $self->error('invalid grade; choose: pass, fail, unknown, na');
-            return;
-        }
-        $self->{_grade} = uc $self->{_grade};
+        $self->{_grade} = uc $self->{_grade} if defined $self->{_grade};
+        $self->_check_grade() || return;
     }
     return $self->{_grade};
 }
@@ -155,50 +144,32 @@ sub new {
     my $type  = shift;
     my $class = ref($type) || $type;
     my $self  = {
-        _archname => undef,     # architecture's name; e.g.: i686-linux-64int
         _comments => undef,     # output of failed 'make test'
-        _config => undef,       # output of Config::myconfig()
-        _dist => undef,         # distribution; e.g.: CPAN-Testers-Report-0.02
+        _config => {},          # container for local perl configuration
+        _dist => undef,         # distribution; e.g.: CPAN-Testers-Report-0.03
         _dist_name => undef,    # distribution's name; e.g. CPAN-Testers-Report
-        _dist_vers => undef,    # distribution's version; e.g.: 0.02
+        _dist_vers => undef,    # distribution's version; e.g.: 0.03
         _from => undef,         # name & e-mail of tester: Foo Bar <foo@bar.com>
         _grade => undef,        # from 'make test'; pass, fail, unknown, or na
         _interpreter              => 'perl', # pugs? (dare I say, ponie?) ...
         _interpreter_vers_extra   => undef,  # patch 1234
         _interpreter_vers_float   => undef,  # 5.008008
         _interpreter_vers_numeric => undef,  # 5.8.8
-        _osname => undef,       # operating system name
-        _osvers => undef,       # operating system version; e.g.: 2.6.22-1-k7
         _report_vers => 1,      # uniquely identifies this test report format
                                 # XXX - ^ - THIS MUST BE INCREMENTED ANY TIME
                                 # XXX - | - ANY TEST REPORT METADATA IS ALTERED
         _rfc2822_date => undef, # RFC2822-compliant date-time
-        _rfc2822_compliance_regex => undef,
         _via => undef,          # caller; e.g.: CPAN, CPANPLUS, CPAN::Reporter
-        __error => undef,
+        __errstr => undef,
     };
 
     bless $self, $class;
 
-    $self->rfc2822_date($self->_format_rfc2822_date());
-    $self->via($self->_compute_via());
-    $self->_rfc2822_compliance_regex($self->_generate_rfc2822_compliance_regex());
+    $self->_init($class) || return;
 
     return $self;
 }
 
-sub osname {
-    my $self = shift;
-    $self->{_osname} = shift if @_;
-    return $self->{_osname};
-}
-
-sub osvers {
-    my $self = shift;
-    $self->{_osvers} = shift if @_;
-    return $self->{_osvers};
-}
-
 sub report_vers {
     my $self = shift;
     return $self->{_report_vers};
@@ -210,27 +181,85 @@ sub rfc2822_date {
     return $self->{_rfc2822_date};
 }
 
+sub validate {
+    my $self = shift;
+
+    $self->_check_grade() || return;
+    $self->_check_from || return;
+
+    unless (defined $self->dist()) {
+        $self->errstr('distribution not specified');
+        return;
+    };
+
+    unless (defined $self->dist_vers()) {
+        $self->errstr("unable to determine distribution version for '${\($self->dist())}'");
+        return;
+    };
+
+    if ($self->_is_a_perl_release($self->dist())) {
+        $self->errstr('use perlbug for reporting test results against perl herself');
+        return;
+    }
+
+    return 1;
+}
+
 sub via {
     my $self = shift;
-    $self->{_via} = shift if @_;
 
-    my $version;
-    {
-        no strict 'refs';
-        $version = ${__PACKAGE__.'::VERSION'};
+    if (@_) {
+        my $version;
+        {
+            no strict 'refs';
+            $version = ${__PACKAGE__.'::VERSION'};
+        }
+
+        my $additional = shift;
+        $self->{_via} = __PACKAGE__ . " $version, $additional";
     }
 
-    if (defined $self->{_via}) {
-        return __PACKAGE__ . " $version, $self->{_via}";
+    return $self->{_via};
+}
+
+sub _check_from {
+    my $self = shift;
+    my $from = $self->from();
+    my $rfc2822_compliance_regex = $self->_rfc2822_compliance_regex();
+
+    unless (defined $from) {
+        $self->errstr('from not specified');
+        return;
     }
-    else {
-        return __PACKAGE__ . " $version";
+
+    unless ($from =~ $rfc2822_compliance_regex) {
+        $self->errstr('invalid from; is not RFC 2822 compliant');
+        return;
     }
+
+    return $from;
+}
+
+sub _check_grade {
+    my $self = shift;
+    my $grade = $self->grade();
+
+    unless (defined $grade) {
+        $self->errstr('grade not specified');
+        return;
+    }
+
+    unless ($grade =~ /^(PASS|FAIL|UNKNOWN|NA)$/i) {
+        $self->errstr('invalid grade; choose: pass, fail, unknown, na');
+        return;
+    }
+
+    return $grade;
 }
 
 sub _compute_via {
     my $self = shift;
-    my $package = (caller(1))[0];
+    my $package = (caller(2))[0];
     my $version;
 
     {   
@@ -244,6 +273,13 @@ sub _compute_via {
     return $via;
 }
 
+sub _configuration_regex {
+    my $self = shift;
+    no strict 'refs';
+    ${__PACKAGE__.'::__CONFIG_RE'} = shift if @_;
+    return ${__PACKAGE__.'::__CONFIG_RE'};
+}
+
 # Derived from CPAN::DistnameInfo by Graham Barr
 sub _distname_info {
     my $self = shift;
@@ -292,56 +328,13 @@ sub _distname_info {
     ($dist, $version, $dev);
 }
 
-# perl -V:archname
-# Derived from CPAN::WWW::Testers::Generator::Article by Leon Brocard
-sub _extract_archname {
-    my $self = shift;
-    my $config = $self->config();
-    my ($archname) = $$config =~ /archname=([^ ,]+)/m;
-
-    if (defined $archname) {
-        $archname =~ s/\n//;
-    }
-    else {
-        $self->error('unable to determine archname');
-    }
-
-    return $archname;
-}
-
-# perl -V:osname
-# Derived from CPAN::WWW::Testers::Generator::Article by Leon Brocard
-sub _extract_osname {
-    my $self = shift;
-    my $config = $self->config();
-    my ($osname) = $$config =~ /osname=(?:3D)?([^ ,]+)/;
-
-    unless (defined $osname) {
-        $self->error('unable to determine osname');
-    }
-
-    return $osname;
-}
-
-# perl -V:osvers
-# Derived from CPAN::WWW::Testers::Generator::Article by Leon Brocard
-sub _extract_osvers {
-    my $self = shift;
-    my $config = $self->config();
-    my ($osvers) = $$config =~ /osvers=([^ ,]+)/;
-
-    unless (defined $osvers) {
-        $self->error('unable to determine osvers');
-    }
-
-    return $osvers;
-}
-
 # Derived from CPAN::WWW::Testers::Generator::Article by Leon Brocard
+# In the future, we may want to investigate alternate methods by
+# which to collect this data without needing to parse myconfig()
 sub _extract_perl_version {
     my $self = shift;
-    my $config = $self->config();
-    my ($rev, $ver, $sub, $extra) = $$config =~ /
+    my $config = Config::myconfig();
+    my ($rev, $ver, $sub, $extra) = $config =~ /
         Summary\sof\smy\s(?:perl\d+)?\s    # Summary of my perl5
         \(                                 # (
         (?:revision\s)?(\d+(?:\.\d+)?)\s   # revision 5
@@ -353,7 +346,7 @@ sub _extract_perl_version {
     /xs;
   
     unless (defined $rev) {
-        $self->error('unable to determine perl version');
+        $self->errstr('unable to determine perl version');
         return;
     }
 
@@ -382,6 +375,13 @@ sub _format_rfc2822_date {
       $day, $mday, $month, $year, $hour, $min, $sec, $direc, $tz_hr, $tz_mi;
 }
 
+sub _generate_configuration_regex {
+    my $self = shift;
+    my $config_keys_regex = join '|', keys %Config;
+
+    return qr/($config_keys_regex)\s?=/;
+}
+
 # Derived from Email::Address by Casey West and Ricardo SIGNES
 sub _generate_rfc2822_compliance_regex {
     my $self                 = shift;
@@ -424,6 +424,36 @@ sub _generate_rfc2822_compliance_regex {
     return $mailbox;
 }
 
+sub _init {
+    my ($self, $class) = @_;
+
+    (my ($vers_numeric, $vers_float, $extra) = $self->_extract_perl_version()) || do {
+        $class->errstr($self->errstr);
+        return;
+    };
+
+    $self->interpreter_vers_numeric($vers_numeric);
+    $self->interpreter_vers_float($vers_float);
+    $self->interpreter_vers_extra($extra);
+    $self->rfc2822_date($self->_format_rfc2822_date());
+    $self->via($self->_compute_via());
+
+    my $configuration_regex = $class->_configuration_regex();
+    my @major_config_keys = Config::myconfig() =~ /$configuration_regex/g;
+    my %major_config;
+
+    for my $major_config_key (@major_config_keys) {
+        if (defined $Config{$major_config_key}) {
+            $major_config{$major_config_key} = $Config{$major_config_key};
+        }
+        else {
+            $major_config{$major_config_key} = undef;
+        }
+    }
+
+    $self->{_config} = \%major_config;
+}
+
 sub _is_a_perl_release {
     my ($self, $dist) = @_;
     return $dist =~ /^perl-?\d\.\d/;
@@ -431,8 +461,9 @@ sub _is_a_perl_release {
 
 sub _rfc2822_compliance_regex {
     my $self = shift;
-    $self->{_rfc2822_compliance_regex} = shift if @_;
-    return $self->{_rfc2822_compliance_regex};
+    no strict 'refs';
+    ${__PACKAGE__.'::__RFC2822_RE'} = shift if @_;
+    return ${__PACKAGE__.'::__RFC2822_RE'};
 }
 
 # Derived from Email::Date by Casey West and Ricardo SIGNES
@@ -456,14 +487,12 @@ CPAN::Testers::Report - Creates CPAN Testers test-report objects
 =head1 SYNOPSIS
 
   use CPAN::Testers::Report;
-  use Config;
 
-  my $test_report = CPAN::Testers::Report->new();
-  $test_report->comments('Rejoice!');
-  $test_report->config(Config::myconfig()) || die $test_report->error();
-  $test_report->dist('Test-Reporter-1.34') || die $test_report->error();
-  $test_report->from('Adam J. Foxson <afoxson@pobox.com>') || die $test_report->error();
-  $test_report->grade('pass') || die $test_report->error();
+  my $test_report = CPAN::Testers::Report->new() || die CPAN::Testers::Report->errstr();
+  $test_report->comments('...This is a computer-generated test report...');
+  $test_report->dist('Test-Reporter-1.34') || die $test_report->errstr();
+  $test_report->from('Adam J. Foxson <afoxson@pobox.com>') || die $test_report->errstr();
+  $test_report->grade('pass') || die $test_report->errstr();
 
 =head1 DESCRIPTION
 
@@ -472,22 +501,117 @@ CPAN::Testers namespace. This module is designed to be part of the
 next-generation implementation of the CPAN Tester's stack. When complete,
 this distribution and its constituents will obsolete Test::Reporter.
 
-This module provides an abstraction for test reports. Objects will encapsulate
-all data and information about a single, specific test report. These objects
-can then be submitted to a user's transport of choice for delivery.
+This module provides an abstraction for test reports. An object of this type
+will encapsulate all data and information about a single, specific test report.
+This object can then be submitted to a user's transport of choice for delivery.
 
 This is a developer's release. The interface is not stable; The API may change
 at any time without notice. This module is not yet recommended for general use.
 
+=head1 SERIALIZATION
+
+These objects are generated specifically with serialization in mind.
+
+Below, please find a sample test report in YAML:
+
+ --- !!perl/hash:CPAN::Testers::Report
+ __errstr: ~
+ _comments: |
+  Dear Adam J. Foxson,
+      
+  This is a computer-generated report for CPAN-Testers-Report-0.03
+  on perl-5.8.8, created automatically by CPAN-Reporter-0.99_15 and sent 
+  to the CPAN Testers mailing list.  
+  
+  If you have received this email directly, it is because the person testing 
+  your distribution chose to send a copy to your CPAN email address; there 
+  may be a delay before the official report is received and processed 
+  by CPAN Testers.
+  
+  Thank you for uploading your work to CPAN.  Congratulations!
+  All tests were successful.
+  
+  <snip!>
+ _config:
+  alignbytes: 8
+  archname: darwin-2level
+  byteorder: 1234
+  cc: /usr/bin/gcc-4.0
+  cccdlflags: ' '
+  ccdlflags: ' '
+  ccflags: -I/opt/local/include -fno-common -DPERL_DARWIN -no-cpp-precomp -fno-strict-aliasing -pipe -Wdeclaration-after-statement -I/opt/local/include
+  ccversion: ''
+  config_args: -des -Dprefix=/opt/local -Dccflags=-I'/opt/local/include' -Dldflags=-L/opt/local/lib -Dvendorprefix=/opt/local -Dcc=/usr/bin/gcc-4.0
+  cppflags: -no-cpp-precomp -I/opt/local/include -fno-common -DPERL_DARWIN -no-cpp-precomp -fno-strict-aliasing -pipe -Wdeclaration-after-statement -I/opt/local/include
+  d_dlsymun: ~
+  d_longdbl: define
+  d_longlong: define
+  d_sfio: ~
+  d_sigaction: define
+  dlext: bundle
+  dlsrc: dl_dlopen.xs
+  doublesize: 8
+  gccosandvers: ''
+  gccversion: '4.0.1 (Apple Computer, Inc. build 5367)'
+  gnulibc_version: ''
+  hint: recommended
+  intsize: 4
+  ivsize: 4
+  ivtype: long
+  ld: env MACOSX_DEPLOYMENT_TARGET=10.3 cc
+  lddlflags: -L/opt/local/lib -bundle -undefined dynamic_lookup
+  ldflags: -L/opt/local/lib
+  libc: /usr/lib/libc.dylib
+  libperl: libperl.a
+  libpth: /opt/local/lib /usr/lib
+  libs: -ldbm -ldl -lm -lc
+  longdblsize: 16
+  longlongsize: 8
+  longsize: 4
+  lseeksize: 8
+  nvsize: 8
+  nvtype: double
+  optimize: -O3
+  osname: darwin
+  osvers: 8.10.1
+  perllibs: -ldl -lm -lc
+  prefix: /opt/local
+  prototype: define
+  ptrsize: 4
+  so: dylib
+  uname: uname
+  use5005threads: ~
+  use64bitall: ~
+  use64bitint: ~
+  useithreads: ~
+  uselargefiles: define
+  uselongdouble: ~
+  usemultiplicity: ~
+  usemymalloc: n
+  useperlio: define
+  useposix: true
+  useshrplib: false
+  usesocks: ~
+  usethreads: ~
+  vendorprefix: /opt/local
+ _dist: CPAN-Testers-Report-0.03
+ _dist_name: CPAN-Testers-Report
+ _dist_vers: 0.03
+ _from: 'Adam J. Foxson <afoxson@pobox.com>'
+ _grade: PASS
+ _interpreter: perl
+ _interpreter_vers_extra: ~
+ _interpreter_vers_float: 5.008008
+ _interpreter_vers_numeric: 5.8.8
+ _interpreter_version_extra: ''
+ _report_vers: 1
+ _rfc2822_date: 'Wed, 3 Oct 2007 23:30:13 -0400'
+ _via: 'CPAN::Testers::Report 0.03, CPAN::Reporter 0.99_15'
+
 =head1 METHODS
 
 =over 4
 
-=item * B<archname>
-
-Automatically calculated but can be overriden. This is a short name to
-characterize the current architecture.
-
 =item * B<comments>
 
 User-specified comments to include with the test report. This is oftentimes
@@ -495,37 +619,38 @@ the output of a failed 'make test'. Optional.
 
 =item * B<config>
 
-This method should be the recipient of Config::myconfig(). Mandatory. If this
-method returns undef, it failed.
+Without an argument returns a list of all of the major configuration items
+(osname, osvers, archname, byteorder, cc, libs, et al...) If given an argument
+will return the value associated with one of those configuration items
 
 =item * B<dist>
 
 Full distribution name and version of which this test report is about. For
-example 'Test-Reporter-1.34'. Mandatory. If this methods returns undef, it
+example 'Test-Reporter-1.34'. Mandatory. If this method returns undef, it
 failed. Attempts to call this method with anything resembling a distribution
 of perl itself will not be honored (use perlbug).
 
 =item * B<dist_name>
 
-Automatically calculated but can be overriden. This represents the
+Automatically calculated but can be overridden. This represents the
 distribution's name only. For example 'Test-Reporter'.
 
 =item * B<dist_vers>
 
-Automatically calculated but can be overriden. This represents the
+Automatically calculated but can be overridden. This represents the
 distribution's version only. For example '1.34'.
 
-=item * B<error>
+=item * B<errstr>
 
-Returns an error message when an error has occurred.
+Returns the error message from the last error that occurred.
 
 =item * B<from>
 
 Name and e-mail address of the tester. For example 'Adam J. Foxson
-<afoxson@pobox.com>'. Optional, but if specified it must be RFC 2822
-compliant. If you ever need to parse this out to separate the name from the
+<afoxson@pobox.com>'. Mandatory, and must be RFC 2822 compliant. Name may be
+omitted. If you ever need to parse this out to separate the name from the
 e-mail address, visit Email::Address. If this method returns undef, it failed
-(i.e., what you specified was not RFC 2822 compliant).
+(i.e., what was specified was not RFC 2822 compliant). This is metadata.
 
 =item * B<grade>
 
@@ -537,36 +662,27 @@ If this method returns undef, it failed.
 
 =item * B<interpreter>
 
-At the moment always returns 'perl'.
+At the moment always returns 'perl' but can be overridden.
 
 =item * B<interpreter_vers_numeric>
 
-Automatically calculated but can be overriden. This represents the
+Automatically calculated but can be overridden. This represents the
 interpreter's version. For example in the format of '5.8.8'.
 
 =item * B<interpreter_vers_float>
 
-Automatically calculated but can be overriden. This represents the
+Automatically calculated but can be overridden. This represents the
 interpreter's version. For example in the format of '5.008008'.
 
 =item * B<interpreter_vers_extra>
 
-Automatically calculated but can be overriden. This usually represents the
+Automatically calculated but can be overridden. This usually represents the
 interpreter's patch/patchlevel, if available. For example 'patchlevel 12345'.
 
 =item * B<new>
 
-Constructor. Accepts no arguments at this time.
-
-=item * B<osname>
-
-Automatically calculated but can be overriden. This is the operating system
-name.
-
-=item * B<osvers>
-
-Automatically calculated but can be overriden. This is the operating system
-version.
+Constructor. Accepts no arguments at this time. If this method returns undef,
+it failed.
 
 =item * B<report_vers>
 
@@ -574,58 +690,29 @@ Revision of the internal test report object format.
 
 =item * B<rfc2822_date>
 
-Automatically calculated but can be overriden. This is the RFC2822-compliant
-datetime.
+Automatically calculated but can be overridden. This is the RFC2822-compliant
+datetime. This is metadata.
+
+=item * B<validate>
+
+Accepts no arguments. Returns true if the object represents a valid test
+report. Returns false and sets errstr() if the object does not represent a
+valid test report. The ensures that that distribution specified is parseable
+into its name/version constituents, that the grade is one of 'pass', 'fail',
+'na', or 'unknown', and that from is present and RFC 2822 compliant
 
 =item * B<via>
 
-Automatically calculated (based on the caller) but can be overriden. This
+Automatically calculated (based on the caller) but can be overridden. This
 represents the automation wrapping CPAN::Testers::Report. This is usually
-something like CPAN::Reporter, CPAN::YACSmoke.
+something like CPAN::Reporter, CPAN::YACSmoke. This is metadata.
 
 =back
 
 =head1 TODO
 
-Please excuse me for a few moments while I think aloud publically. :-)
-
 =over 4
 
-=item * Add tests for error conditions
-
-At a minimum:
-
-=over 4
-
-=item * dist()
-
-=item * from()
-
-=item * grade()
-
-=item * config()
-
-=back
-
-=item * Add a validate() method to ensure overall consistency?
-
-This is not intended to indicate suitablity for any particular transport. This
-is more about verifying that the object contains the minimum necessary data
-and in a correct form to even be considered a valid test report. A transport
-could call this as a sanity check before attempting delivery.
-
-=over 4
-
-=item * a distribution that is parseable into its name and version components
-
-=item * a config that is parseable into its archname, osvers, and perl version components
-
-=item * a from, if specified, must be RFC 2822 compliant
-
-=item * a grade that is one of 'pass', 'fail', 'na', or 'unknown'
-
-=back
-
 =item * Decide what to do about "interpreter"
 
 The idea behind this is that CPAN modules might theoretically be able to be
@@ -638,30 +725,6 @@ The question is whether or not we want to actually accomodate for this
 possibility. Or to restate, do we want to have support for testing CPAN
 distributions with interpreters that are "perl-like"?
 
-=item * Shall the metadata be handled specially (from/date/via) ?
-
-These are all three bits of data that are arguably part of a test-report, but
-a test-report can be fully 100% valid in all of their absence. As such, I'm
-wondering if we want to handle these differently/specially. Food for thought!
-
-=item * RFC 2822 compliance regex shouldn't be assembled on a per object basis
-
-This is inefficient and needs to be addressed.
-
-=item * Hmm. What to do about the subject...
-
-Doesn't really belong in this module (because the concept of 'Subject' is
-specfic only to a particular class of transport), but we don't want each e-mail
-based transport reimplementing this functionality or duplicating code. And, we
-need the flexibility to change it in the future without major disruption. So
-then, what we might want to do is create a new distribution that provides
-methods to do both parsing and generating of subjects, once passed a
-previously generated subject or CPAN::Testers::Report object.
-
-=item * Hmm. What to do about the "stringified formatted report"...
-
-Almost 3am! Time for bed... More to come tomorrow...
-
 =back
 
 =head1 COPYRIGHT
